@@ -1,6 +1,8 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 from .conv2plus1d import Conv2plus1d
 from .conv_audio import ConvAudio
 from .lfb import LFB
+from .sub_batchnorm3d import SubBatchNorm3D
 from .tam import TAM
 from .transformer import (DividedSpatialAttentionWithNorm,
                           DividedTemporalAttentionWithNorm, FFNWithNorm)
@@ -8,5 +10,5 @@ from .transformer import (DividedSpatialAttentionWithNorm,
 __all__ = [
     'Conv2plus1d', 'ConvAudio', 'LFB', 'TAM',
     'DividedSpatialAttentionWithNorm', 'DividedTemporalAttentionWithNorm',
-    'FFNWithNorm'
+    'FFNWithNorm', 'SubBatchNorm3D'
 ]
