@@ -1,4 +1,5 @@
 # Copyright (c) OpenMMLab. All rights reserved.
+import numpy as np
 import torch
 import torch.nn.functional as F
 
@@ -119,3 +120,72 @@ class BCELossWithLogits(BaseWeightedLoss):
         loss_cls = F.binary_cross_entropy_with_logits(cls_score, label,
                                                       **kwargs)
         return loss_cls
+
+
+@LOSSES.register_module()
+class CBFocalLoss(BaseWeightedLoss):
+    """Class Balanced Focal Loss. Adapted from https://github.com/abhinanda-
+    punnakkal/BABEL/. This loss is used in the skeleton-based action
+    recognition baseline for BABEL.
+
+    Args:
+        loss_weight (float): Factor scalar multiplied on the loss.
+            Default: 1.0.
+        samples_per_cls (list[int]): The number of samples per class.
+            Default: [].
+        beta (float): Hyperparameter that controls the per class loss weight.
+            Default: 0.9999.
+        gamma (float): Hyperparameter of the focal loss. Default: 2.0.
+    """
+
+    def __init__(self,
+                 loss_weight=1.0,
+                 samples_per_cls=[],
+                 beta=0.9999,
+                 gamma=2.):
+        super().__init__(loss_weight=loss_weight)
+        self.samples_per_cls = samples_per_cls
+        self.beta = beta
+        self.gamma = gamma
+        effective_num = 1.0 - np.power(beta, samples_per_cls)
+        weights = (1.0 - beta) / np.array(effective_num)
+        weights = weights / np.sum(weights) * len(weights)
+        self.weights = weights
+        self.num_classes = len(weights)
+
+    def _forward(self, cls_score, label, **kwargs):
+        """Forward function.
+
+        Args:
+            cls_score (torch.Tensor): The class score.
+            label (torch.Tensor): The ground truth label.
+            kwargs: Any keyword argument to be used to calculate
+                bce loss with logits.
+
+        Returns:
+            torch.Tensor: The returned bce loss with logits.
+        """
+        weights = torch.tensor(self.weights).float().to(cls_score.device)
+        label_one_hot = F.one_hot(label, self.num_classes).float()
+        weights = weights.unsqueeze(0)
+        weights = weights.repeat(label_one_hot.shape[0], 1) * label_one_hot
+        weights = weights.sum(1)
+        weights = weights.unsqueeze(1)
+        weights = weights.repeat(1, self.num_classes)
+
+        BCELoss = F.binary_cross_entropy_with_logits(
+            input=cls_score, target=label_one_hot, reduction='none')
+
+        modulator = 1.0
+        if self.gamma:
+            modulator = torch.exp(-self.gamma * label_one_hot * cls_score -
+                                  self.gamma *
+                                  torch.log(1 + torch.exp(-1.0 * cls_score)))
+
+        loss = modulator * BCELoss
+        weighted_loss = weights * loss
+
+        focal_loss = torch.sum(weighted_loss)
+        focal_loss /= torch.sum(label_one_hot)
+
+        return focal_loss
